// Copyright 2024 Mathias Bynens. All rights reserved.
// This code is governed by the BSD license found in the LICENSE file.

/*---
author: Mathias Bynens
description: >
  Unicode property escapes for `Script_Extensions=Old_Permic`
info: |
  Generated by https://github.com/mathiasbynens/unicode-property-escapes-tests
  Unicode v16.0.0
esid: sec-static-semantics-unicodematchproperty-p
features: [regexp-unicode-property-escapes]
includes: [regExpUtils.js]
---*/

const matchSymbols = buildString({
  loneCodePoints: [
    0x0000B7,
    0x000300,
    0x000313,
    0x000483
  ],
  ranges: [
    [0x000306, 0x000308],
    [0x010350, 0x01037A]
  ]
});
testPropertyEscapes(
  /^\p{Script_Extensions=Old_Permic}+$/u,
  matchSymbols,
  "\\p{Script_Extensions=Old_Permic}"
);
testPropertyEscapes(
  /^\p{Script_Extensions=Perm}+$/u,
  matchSymbols,
  "\\p{Script_Extensions=Perm}"
);
testPropertyEscapes(
  /^\p{scx=Old_Permic}+$/u,
  matchSymbols,
  "\\p{scx=Old_Permic}"
);
testPropertyEscapes(
  /^\p{scx=Perm}+$/u,
  matchSymbols,
  "\\p{scx=Perm}"
);

const nonMatchSymbols = buildString({
  loneCodePoints: [],
  ranges: [
    [0x00DC00, 0x00DFFF],
    [0x000000, 0x0000B6],
    [0x0000B8, 0x0002FF],
    [0x000301, 0x000305],
    [0x000309, 0x000312],
    [0x000314, 0x000482],
    [0x000484, 0x00DBFF],
    [0x00E000, 0x01034F],
    [0x01037B, 0x10FFFF]
  ]
});
testPropertyEscapes(
  /^\P{Script_Extensions=Old_Permic}+$/u,
  nonMatchSymbols,
  "\\P{Script_Extensions=Old_Permic}"
);
testPropertyEscapes(
  /^\P{Script_Extensions=Perm}+$/u,
  nonMatchSymbols,
  "\\P{Script_Extensions=Perm}"
);
testPropertyEscapes(
  /^\P{scx=Old_Permic}+$/u,
  nonMatchSymbols,
  "\\P{scx=Old_Permic}"
);
testPropertyEscapes(
  /^\P{scx=Perm}+$/u,
  nonMatchSymbols,
  "\\P{scx=Perm}"
);
